# J.A.I.son GRPC

This is a package containing the [grpc](https://github.com/grpc/grpc) objects necessary for [Project J.A.I.son components](https://github.com/limitcantcode/jaison-component-template) to communicate with [Project J.A.I.son core](https://github.com/limitcantcode/J.A.I.son) and vice versa.

Unless making your own component implementation without the component template, you won't need to refer to this. In case you are, the protobuf files are included [here](https://github.com/limitcantcode/jaison-grpc/tree/main/proto).

## Contributing
I am accepting contributions for this package. If you would like to contribute, please refer to [CONTRIBUTING](https://github.com/limitcantcode/jaison-grpc/tree/main/CONTRIBUTING.md).